@@ -1,4 +1,5 @@
 import enum
+from pydantic import BaseModel
 from graphql_api import GraphQLAPI, field
 
 from graphql_mcp.server import GraphQLMCP
@@ -9,6 +10,12 @@ class PreferenceKey(str, enum.Enum):
     TOOLS_ENABLED = "tools_enabled"
 
 
+class PydanticTest(BaseModel):
+    key: str
+    value: str
+    number: int
+
+
 class DemoApp:
 
     @field
@@ -24,6 +31,11 @@ class DemoApp:
         """Get a preference"""
         return {"key": "ai_model", "value": "x"}
 
+    @field
+    def get_pydantic_test(self) -> PydanticTest:
+        """Get a pydantic test"""
+        return PydanticTest(key="ai_model", value="x", number=1)
+
 
 mcp_server = GraphQLMCP.from_api(api=GraphQLAPI(root_type=DemoApp))
 
